Django Grappelli
================
.. image:: https://github.com/sehmaschine/django-grappelli/actions/workflows/tests.yml/badge.svg?branch=master
    :target: https://github.com/sehmaschine/django-grappelli/actions/workflows/tests.yml?query=branch%3Amaster

.. image:: https://readthedocs.org/projects/django-grappelli/badge/?version=latest
    :target: http://django-grappelli.readthedocs.org/en/latest/?badge=latest

.. image:: https://img.shields.io/pypi/v/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

.. image:: https://img.shields.io/pypi/l/django-grappelli.svg
    :target: https://pypi.python.org/pypi/django-grappelli

**A jazzy skin for the Django admin interface**.

Grappelli is a grid-based alternative/extension to the `Django <http://www.djangoproject.com>`_ administration interface.

Code
----

https://github.com/sehmaschine/django-grappelli

Website
-------

http://www.grappelliproject.com

Documentation
-------------

https://django-grappelli.readthedocs.io/en/latest/

Releases
--------

**Grappelli is always developed against the latest stable Django release and is NOT tested with Django's master branch.**

* Grappelli 4.0.2 (April 28th, 2025): Compatible with Django 5.x
* Grappelli 3.0.10 (April 28th, 2025): Compatible with Django 4.2 (LTS)

Current development branches:

* Grappelli 4.0.3 (Development version for Django 5.0, see branch Stable/4.0.x)
* Grappelli 3.0.11 (Development version for Django 4.0, see branch Stable/3.0.x)

Older versions are available at GitHub, but are not supported anymore.
